@@ -1,3 +1,23 @@
+
+## defaults to src
+
+.getExt = function(repourl = "./src/contrib", regex = FALSE) {
+    typ = gsub(".*/(.*)/contrib", "\\1", repourl)
+    res = switch(typ,
+           src = ".tar.gz",
+           win = ".zip",
+           mac = ".tgz",
+           ## XXX this assumes source unless it gets something that matches the regex
+           ## above.
+           ".tar.gz")
+    if(regex)
+        res =  gsub(".", "\\.", res, fixed = TRUE)
+    res
+}
+
+
+
+
 ## (very far backawards compatible version of list.dirs
 ## list.dirs is apparently a relatively new addition, makes this function fail in R 2.12.1
 list.dirs = function(path = ".", full.names = TRUE, recursive = TRUE) {
@@ -226,15 +246,12 @@ makePwdFun = function(scm_auth, url)
 ##' @export
 makeSource = function(url, type, user, password, scm_auth = list(), prefer_svn = FALSE, ...) {
     if(is.na(url) && is.na(type)) {
-        if(requireNamespace("BiocManager"))
-            repos = BiocManager::repositories()
-        else if (requireNamespace2("BiocInstaller"))
-            repos = BiocInstaller::biocinstallRepos()
-        else {
-            repos  = getOption("repos")
-            if(identical(repos, "@CRAN@") && !interactive())
-                chooseCRANmirror(ind = 1L)
-        }
+        repos = c(getOption("repos"), getBiocRepos())
+        repos = repos[!duplicated(names(repos))]
+        atcran = grep("@CRAN@", repos)
+        if(length(atcran) > 0 && !interactive())
+            chooseCRANmirror(ind = 1L)
+
         ## name is passed in as a ... here, and usually not needed
         ## but it is needed if we are trying to find the url/type
         ## of a package
